"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = featureContent;

var React = _interopRequireWildcard(require("react"));

var _lodash = require("lodash");

var _reactRedux = require("react-redux");

var _reselect = require("reselect");

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function featureContent(options) {
  const {
    getFeatures,
    sortFeatures,
    getContent
  } = (0, _lodash.defaults)({}, options, {
    getFeatures: state => state ? state.features : {},
    sortFeatures: features => Object.values(features)
  });
  const mapStateToProps = (0, _reselect.createStructuredSelector)({
    features: (0, _reselect.createSelector)(getFeatures, sortFeatures)
  });

  function mergeProps({
    features
  }, dispatchProps, _ref) {
    let {
      children
    } = _ref,
        props = _objectWithoutProperties(_ref, ["children"]);

    const content = [];
    features.forEach((feature, featureIndex) => {
      let featureContent = getContent(feature);
      if (featureContent == null) return;
      if (typeof featureContent === 'function') featureContent = featureContent(props);
      if (!Array.isArray(featureContent)) featureContent = [featureContent];
      featureContent.forEach((item, index) => {
        if (React.isValidElement(item) && item.key == null) {
          item = React.cloneElement(item, {
            key: featureIndex + ':' + index
          });
        }

        content.push(item);
      });
    });
    return {
      children: children instanceof Function ? children(content) : React.createElement(React.Fragment, null, content)
    };
  }

  const FeatureContent = ({
    children
  }) => children;

  return (0, _reactRedux.connect)(mapStateToProps, null, mergeProps)(FeatureContent);
}